@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: maprgbapng.c 7960 2008-10-05 15:59:44Z tbonfort $
+ * $Id: maprgbapng.c 12586 2011-09-25 13:10:06Z tbonfort $
  *
  * Project:  MapServer
  * Purpose:  PNG related functions for use with RGBA imagetypes
@@ -105,6 +105,14 @@ static void ms_png_error_handler(png_structp png_ptr, png_const_charp msg)
     longjmp(ms_ptr->jmpbuf, 1);
 }
 
+
+/* newer versions of libpng do not include zlib.h, so we
+ * define the compression value here
+ */
+#ifndef Z_BEST_COMPRESSION
+#define Z_BEST_COMPRESSION       9
+#endif
+
 int ms_png_write_image_init(gdIOCtx *ctx, ms_png_info *ms_ptr)
 {
     png_structp png_ptr;       /* note:  temporary variables! */
