@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: mapsymbol.c 8859 2009-04-02 01:25:31Z sdlime $
+ * $Id: mapsymbol.c 9657 2010-01-03 14:28:28Z tamas $
  *
  * Project:  MapServer
  * Purpose:  symbolObj related functions.
@@ -35,7 +35,7 @@
 #include "mapcopy.h"
 #include "mapthread.h"
 
-MS_CVSID("$Id: mapsymbol.c 8859 2009-04-02 01:25:31Z sdlime $")
+MS_CVSID("$Id: mapsymbol.c 9657 2010-01-03 14:28:28Z tamas $")
 
 extern int msyylex(void); /* lexer globals */
 extern void msyyrestart(FILE *);
@@ -58,7 +58,7 @@ void freeImageCache(struct imageCacheObj *ic)
 {
   if(ic) {
     freeImageCache(ic->next); /* free any children */
-    gdImageDestroy(ic->img);
+   	gdImageDestroy(ic->img);
     free(ic);  
   }
   return;
@@ -134,12 +134,15 @@ void initSymbol(symbolObj *s)
   s->numpoints=0;
   s->img = NULL;
   s->renderer_cache=NULL;
+  s->renderer=NULL;
+  s->pixmap_buffer=NULL;
   s->imagepath = NULL;
   s->name = NULL;
   s->gap = 0;
   s->inmapfile = MS_FALSE;
   s->antialias = MS_FALSE;
   s->font = NULL;
+  s->full_font_path = NULL;
   s->character = NULL;
   s->position = MS_CC;
 
@@ -156,10 +159,20 @@ int msFreeSymbol(symbolObj *s) {
   
   if(s->name) free(s->name);
   if(s->img) gdImageDestroy(s->img);
+  if(s->renderer!=NULL) {
+	  s->renderer->freeSymbol(s);
+  }
 #ifdef USE_AGG
-  if(s->renderer_cache) msFreeSymbolCacheAGG(s->renderer_cache);
+  else
+	  if(s->renderer_cache) msFreeSymbolCacheAGG(s->renderer_cache);
 #endif
+  if(s->pixmap_buffer) {
+      msFreeRasterBuffer(s->pixmap_buffer);
+      free(s->pixmap_buffer);
+  }
+
   if(s->font) free(s->font);
+  msFree(s->full_font_path);
   if(s->imagepath) free(s->imagepath);
   if(s->character) free(s->character);
   
@@ -293,7 +306,7 @@ int loadSymbol(symbolObj *s, char *symbolpath)
 	switch(msyylex()) {  
 	case(END):
 	  if(s->patternlength < 2) {
-	    msSetError(MS_SYMERR, "Not enough pattern elements. A minimum of 2 are required.", "loadSymbol()");
+	    msSetError(MS_SYMERR, "Not enough pattern elements. A minimum of 2 are required", "loadSymbol()");
 	    return(-1);
 	  }	  
 	  done = MS_TRUE;
@@ -316,21 +329,20 @@ int loadSymbol(symbolObj *s, char *symbolpath)
       break;
     case(POINTS):
       done = MS_FALSE;
-      s->sizex = s->sizey = 0;
+      s->sizex = 0;
+      s->sizey = 0;
       for(;;) {
 	switch(msyylex()) { 
 	case(END):
-          if(s->numpoints < 1) {
-            msSetError(MS_SYMERR, "Not enough points are defined", "loadSymbol()");
-            return(-1);
-          }
 	  done = MS_TRUE;
 	  break;
 	case(MS_NUMBER):
 	  s->points[s->numpoints].x = atof(msyytext); /* grab the x */
 	  if(getDouble(&(s->points[s->numpoints].y)) == -1) return(-1); /* grab the y */
+	  if(s->points[s->numpoints].x!=-99) {
 	  s->sizex = MS_MAX(s->sizex, s->points[s->numpoints].x);
-	  s->sizey = MS_MAX(s->sizey, s->points[s->numpoints].y);	
+	  s->sizey = MS_MAX(s->sizey, s->points[s->numpoints].y);
+	  }
 	  s->numpoints++;
 	  break;
 	default:
@@ -375,7 +387,7 @@ void writeSymbol(symbolObj *s, FILE *stream)
   
   switch (s->type) {
   case(MS_SYMBOL_HATCH):
-    /* todo! */
+    fprintf(stream, "    TYPE HATCH\n");
     break;
   case(MS_SYMBOL_PIXMAP):
     fprintf(stream, "    TYPE PIXMAP\n");
